@@ -37,7 +37,7 @@
 
 pref("general.useragent.vendor", "Thunderbird");
 pref("general.useragent.vendorSub", 
-"1.0.7"
+"1.0.8"
 );
 
 // This is this application's unique identifier used by the Extension System to identify
@@ -45,10 +45,10 @@ pref("general.useragent.vendorSub",
 // this application to the Update server.
 pref("app.id", "{3550f703-e582-4d05-9a08-453d09bdfdc6}");
 pref("app.version", 
-"1.0.7"
+"1.0.8"
 );
 pref("app.build_id", 
-"2005092314"
+"2006041710"
 );
 pref("app.extensions.version", "1.0");
 
@@ -162,7 +162,7 @@ pref("mail.checkDefaultNews", false);
 /////////////////////////////////////////////////////////////////
 
 // l12n and i18n
-pref("general.useragent.locale", "ru-RU");
+pref("general.useragent.locale", "en-US");
 pref("general.skins.selectedSkin", "classic/1.0");
 
 pref("intl.charsetmenu.mailedit", "chrome://global/locale/intl.properties");
